@@ -25,20 +25,11 @@ from saltfactories.utils import ports
 class MinionFactory(object):
     @staticmethod
     def default_config(
-        factories_root_dir, minion_id, default_options=None, config_overrides=None, master_port=None
+        root_dir, minion_id, default_options=None, config_overrides=None, master_port=None
     ):
         if default_options is None:
             default_options = salt.config.DEFAULT_MINION_OPTS.copy()
 
-        counter = 1
-        root_dir = factories_root_dir.join(minion_id)
-        while True:
-            if not root_dir.check(dir=True):
-                break
-            root_dir = factories_root_dir.join("{}_{}".format(minion_id, counter))
-            counter += 1
-        root_dir.ensure(dir=True)
-
         conf_dir = root_dir.join("conf").ensure(dir=True)
         conf_file = conf_dir.join("minion").strpath
 
